@@ -1,6 +1,6 @@
 import glob
 import os
-from p2k.climate import ClimateField, ClimateDataset
+from .climate import ClimateField, ClimateDataset
 import xarray as xr
 import pandas as pd
 import numpy as np
@@ -217,7 +217,7 @@ class ProxyRecord:
         if hasattr(self, 'clim'): del self.clim
         if verbose: utils.p_success(f'ProxyRecord.clim deleted for {self.pid}.')
 
-    def get_clim(self, fields, tag=None, verbose=True, **kwargs):
+    def get_clim(self, fields, tag=None, verbose=True, load=True, **kwargs):
         ''' Get the nearest climate from cliamte fields
 
         Parameters
@@ -243,10 +243,11 @@ class ProxyRecord:
                 self.clim = {}
 
             self.clim[name] = ClimateField().from_da(nda)
+            if load: self.clim[name].da.load()
             if verbose: utils.p_success(f'ProxyRecord.clim["{name}"] created.')
 
 
-    def plotly(self, mute=False, **kwargs):
+    def plotly(self, **kwargs):
         import plotly.express as px
         time_lb = visual.make_lb(self.time_name, self.time_unit)
         value_lb = visual.make_lb(self.value_name, self.value_unit)
@@ -259,12 +260,9 @@ class ProxyRecord:
             **_kwargs,
         )
 
-        if not mute:
-            fig.show()
-
         return fig
 
-    def plot(self, mute=False, figsize=[12, 4], legend=False, ms=200, stock_img=True, edge_clr='w',
+    def plot(self, figsize=[12, 4], legend=False, ms=200, stock_img=True, edge_clr='w',
         wspace=0.1, hspace=0.1, plot_map=True, **kwargs):
         if 'color' not in kwargs and 'c' not in kwargs:
             kwargs['color'] = visual.PAGES2k.colors_dict[self.ptype]
@@ -309,9 +307,6 @@ class ProxyRecord:
                 s=ms, c=kwargs['color'], edgecolor=edge_clr, transform=transform,
             )
 
-        if not mute:
-            visual.showfig(fig)
-
         return fig, ax
 
 
@@ -487,7 +482,7 @@ class ProxyDatabase:
         new_db.refresh()
         return new_db
 
-    def plot(self, mute=False, **kws):
+    def plot(self, **kws):
 
         time_list = []
         for pid, pobj in self.records.items():
@@ -496,9 +491,6 @@ class ProxyDatabase:
         df = pd.DataFrame({'lat': self.lats, 'lon': self.lons, 'type': self.type_list, 'time': time_list})
         fig, ax = visual.plot_proxies(df, **kws)
 
-        if not mute:
-            visual.showfig(fig)
-
         return fig, ax
 
     def annualize(self, months=list(range(1, 13))):
@@ -528,11 +520,11 @@ class ProxyDatabase:
         new.refresh()
         return new
 
-    def get_clim(self, field, tag=None, verbose=False, **kwargs):
+    def get_clim(self, field, tag=None, verbose=False, load=True, **kwargs):
 
         new = ProxyDatabase()
         for pid, pobj in tqdm(self.records.items(), total=self.nrec, desc='Getting the nearest climate for ProxyRecord'):
-            pobj.get_clim(field, tag=tag, verbose=verbose, **kwargs)
+            pobj.get_clim(field, tag=tag, verbose=verbose, load=load, **kwargs)
             new += pobj
 
         new.refresh()
